@@ -3,6 +3,7 @@ from typing import Callable, Sequence, Type, Union
 import jax
 import jax.experimental.host_callback as hcb
 import jax.numpy as jnp
+import numpy as np
 
 from ..custom_types import Array, Int
 from .unvmap import unvmap_any
@@ -17,10 +18,14 @@ def error_if(
     error_cls: Type[Exception] = ValueError,
 ) -> bool:
     """For use as part of validating inputs.
+    Works even under JIT.
 
     Example:
+        @jax.jit
         def f(x):
             error_if(x < 0, "x must be >= 0")
+
+        f(jax.numpy.array(-1))
     """
     branched_error_if(pred, 0, [msg], error_cls)
 
@@ -48,11 +53,12 @@ def branched_error_if(
 
     if isinstance(pred, jax.core.Tracer):
         hcb.call(raises, (pred, index))
-    elif isinstance(pred, (bool, jnp.ndarray)):
+    elif isinstance(pred, (bool, np.ndarray, jnp.ndarray)):
         raises((pred, index))
     else:
         msg = (
             "`pred` must either be a `bool`, a JAX array, or a zero-argument callable "
-            "that returns a `bool` or JAX array."
+            "that returns a `bool` or JAX array, instead we got "
+            f"value: {pred} of type: {type(pred)}."
         )
         assert False, msg
